==> php81-nextcloud-28.0.2.tgz: share/nextcloud/apps/password_policy/l10n/ja.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "パスワードの有効期限が切れています。「パスワードをお忘れですか？」のリンクからパスワードの再設定をお試しください。",
    "Password must not have been used recently before." : "パスワードは、最近使用されたものではありません。",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "パスワードは最も一般的なパスワード1,000,000個の中に入っています。もっと違うものにしてください。",
    "Password is present in compromised password list. Please choose a different password." : "現在のパスワードは危険なパスワードリストに含まれるものです。別のパスワードを選択してください。",
    "Password needs to be at least %s characters long." : "パスワードは少なくとも%s文字以上の長さである必要があります。",
    "Password needs to contain at least one numeric character." : "パスワードは1つ以上の数字を含む必要があります",
    "Password needs to contain at least one special character." : "パスワードは1つ以上の特別な文字を含む必要があります",
    "Password needs to contain at least one lower and one upper case character." : "パスワードは1つ以上の大文字と小文字をそれぞれ含む必要があります",
    "Password policy" : "パスワードポリシー",
    "Allows admins to configure a password policy" : "管理者がパスワードポリシーを設定することを許可します",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "管理者が事前に一定の制約をパスワードに課すことを許可します。（例：最小の長さを強制）",
    "Minimum password length" : "最低限のパスワードの長さ",
    "User password history" : "ユーザーのパスワード履歴",
    "Number of days until user password expires" : "ユーザーのパスワードが失効するまでの日数",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "ユーザーアカウントがブロックされるまでのログイン試行回数 (制限なしの場合は0)",
    "Forbid common passwords" : "一般的なパスワードを禁止する",
    "Enforce upper and lower case characters" : "大文字と小文字を必ず含む",
    "Enforce numeric characters" : "数字を必ず含む",
    "Enforce special characters" : "記号を必ず含む",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "haveibeenpwned.comの侵害されたパスワードのリストと比較してパスワードをチェックする",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "このチェックでは、パスワードのハッシュを生成して先頭5文字をhaveibeenpwned.com APIに送信し、その5文字から始まるすべてのハッシュリストを取得します。 そして、パスワードハッシュが結果セットに含まれているかどうかNextcloudサーバーをチェックします。",
    "Unknown error" : "不明なエラー",
    "Minimal length has to be a non negative number" : "最小の長さにマイナスの数は設定できません",
    "History size has to be a non negative number" : "履歴サイズにマイナスの数は設定できません",
    "Expiration days have to be a non negative number" : "有効期限にマイナスの数は設定できません",
    "Maximum login attempts have to be a non negative number" : "最大ログイン試行回数にマイナスの数は設定できません",
    "Settings saved" : "設定が保存されました",
    "Error while saving settings" : "設定の保存中にエラーが発生",
    "Saved" : "保存しました",
    "Error while saving" : "保存中にエラーが発生しました"
},
"nplurals=1; plural=0;");

==> php81-nextcloud-30.0.11.tgz: share/nextcloud/apps/password_policy/l10n/ja.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "パスワードの有効期限が切れています。「パスワードをお忘れですか？」のリンクからパスワードの再設定をお試しください。",
    "Password must not have been used recently before." : "パスワードは、最近使用されたものではありません。",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "パスワードは最も一般的なパスワード1,000,000個の中に入っています。もっと違うものにしてください。",
    "Password is present in compromised password list. Please choose a different password." : "現在のパスワードは危険なパスワードリストに含まれるものです。別のパスワードを選択してください。",
    "Password needs to be at least %s characters long." : "パスワードは少なくとも%s文字以上の長さである必要があります。",
    "Password needs to contain at least one numeric character." : "パスワードは1つ以上の数字を含む必要があります",
    "Password needs to contain at least one special character." : "パスワードは1つ以上の特別な文字を含む必要があります",
    "Password needs to contain at least one lower and one upper case character." : "パスワードは1つ以上の大文字と小文字をそれぞれ含む必要があります",
    "Password policy" : "パスワードポリシー",
    "Allows admins to configure a password policy" : "管理者がパスワードポリシーを設定することを許可します",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "管理者が事前に一定の制約をパスワードに課すことを許可します。（例：最小の長さを強制）",
    "General password policies" : "一般的なパスワードポリシー",
    "Add policy set" : "ポリシーセットを追加",
    "Login policies" : "ログインポリシー",
    "Password history size" : "パスワード履歴のサイズ",
    "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords." : "ユーザーが以前に使用したパスワードを再利用するのを防ぐために、（安全にハッシュ化された）パスワードを保持する数。",
    "Maximum login attempts" : "最大ログイン試行回数",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "手動アクションによる処置が行われるまでユーザー アカウントが無効になるまでのログイン試行回数。(制限なしの場合は 0)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "このオプションはアカウント攻撃から守るためです",
    "Number of days until user password expires" : "ユーザーのパスワードが失効するまでの日数",
    "Password expiration" : "パスワードの有効期限",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "警告:パスワードの有効期限を有効にすることは、いくつかのセキュリティ機関によってセキュリティリスクと見なされています。",
    "Remove policy" : "ポリシーを削除",
    "Minimum password length" : "最低限のパスワードの長さ",
    "Forbid common passwords" : "一般的なパスワードを禁止する",
    "Enforce upper and lower case characters" : "大文字と小文字を必ず含む",
    "Enforce numeric characters" : "数字を必ず含む",
    "Enforce special characters" : "記号を必ず含む",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "haveibeenpwned.comの侵害されたパスワードのリストと比較してパスワードをチェックする",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "このチェックでは、パスワードのハッシュを生成して先頭5文字をhaveibeenpwned.com APIに送信し、その5文字から始まるすべてのハッシュリストを取得します。 そして、パスワードハッシュが結果セットに含まれているかどうかNextcloudサーバーをチェックします。",
    "Account password policies" : "アカウントパスワードポリシー",
    "Share password policies" : "パスワードポリシーの共有",
    "Unknown error" : "不明なエラー",
    "Minimal length has to be a non negative number" : "最小の長さにマイナスの数は設定できません",
    "History size has to be a non negative number" : "履歴サイズにマイナスの数は設定できません",
    "Expiration days have to be a non negative number" : "有効期限にマイナスの数は設定できません",
    "Maximum login attempts have to be a non negative number" : "最大ログイン試行回数にマイナスの数は設定できません",
    "Settings saved" : "設定が保存されました",
    "Error while saving settings" : "設定の保存中にエラーが発生",
    "User password history" : "ユーザーのパスワード履歴",
    "Please note, that this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "このオプションは攻撃されたアカウントを保護するためのものであることに注意してください。無効にされたアカウントは、管理者が手動で再度有効にする必要があります。アカウントのパスワードを推測しようとする攻撃者は、この設定とは無関係にブルートフォース保護によってIPアドレスがブロックされます。"
},
"nplurals=1; plural=0;");
